==> ws-v3.80.5-src.tar.gz: ws-v3.80-5/include/advance/WSCtriggerEditor.h <==
//
// Copyright (C) 1999-2004 WideStudio Development Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of WideStudio Development Team
// shall not be used in advertising or otherwise to promote the sale, use or
// other dealings in this Software without prior written authorization from
// WideStudio Development Team.

#ifndef WSCtriggerEditor_H
#define WSCtriggerEditor_H
#include <WScom.h>
#include <WSDappDev.h>
#define WSCtriggerEditor_VER 1000
#include <WSCbaseDialog.h>

class WSCform;
class WSCvbtn;
class WSCvlabel;
class WSClist;
class WSCoption;
class WSCmessageDialog;

#define WSCtriggerEditorBASETYPE WSCbaseDialog

class WSCtriggerEditor :public WSCtriggerEditorBASETYPE  {

  private:
    void* _reply_hd;
    void* _client;
    WSCform* _trgsarea001;
    WSClist* _trgslist008;
    WSCoption* _trgsopti009;

    protected:
    WSMFpropertyDef(WSNreplyHandler,void*,_reply_hd);
    WSMFpropertyDef(WSNclient,void*,_client);

    void setWorkWSNwidth(WSCushort);
    void setWorkWSNheight(WSCushort);


    WSClist* trgslist008;
    WSCoption* trgsopti009;

    void _property_delete();
    virtual void onActivate();
    virtual void onResize(WSCrect* rect);

    void _adjust();
  public:
virtual     long initialize();

   static void visop(WSCbase*);
   static void endop(WSCbase*);
   static void setop(WSCbase*);
   static void addop(WSCbase*);
   static void delop(WSCbase*);

  protected:
     WSCmessageDialog* _msg;

  public:
     WSCtriggerEditor(WSCbase* base,char* name);
    virtual ~WSCtriggerEditor();
     WSClist* getList();
    virtual void onGuiPolicyChange(long);

    WSMFguiClassDef(WSCtriggerEditor,WSCtriggerEditorBASETYPE );
    WSMFversionDef(WSCtriggerEditor);
};
#endif

==> ws-v3.93.2-src.tar.gz: ws-v3.93-2/include/advance/WSCtriggerEditor.h <==
//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

#ifndef WSCtriggerEditor_H
#define WSCtriggerEditor_H
#include <WScom.h>
#include <WSDappDev.h>
#define WSCtriggerEditor_VER 1000
#include <WSCbaseDialog.h>

class WSCform;
class WSCvbtn;
class WSCvlabel;
class WSClist;
class WSCoption;
class WSCmessageDialog;

#define WSCtriggerEditorBASETYPE WSCbaseDialog

class WSCtriggerEditor :public WSCtriggerEditorBASETYPE  {

  private:
    void* _reply_hd;
    void* _client;
    WSCform* _trgsarea001;
    WSClist* _trgslist008;
    WSCoption* _trgsopti009;

    protected:
    WSMFpropertyDef(WSNreplyHandler,void*,_reply_hd);
    WSMFpropertyDef(WSNclient,void*,_client);

    WSDLEX32 void setWorkWSNwidth(WSCushort);
    WSDLEX32 void setWorkWSNheight(WSCushort);


    WSClist* trgslist008;
    WSCoption* trgsopti009;

    WSDLEX32 void _property_delete();
    WSDLEX32 virtual void onActivate();
    WSDLEX32 virtual void onResize(WSCrect* rect);

    WSDLEX32 void _adjust();
  public:
WSDLEX32 virtual     long initialize();

    WSDLEX32 static void visop(WSCbase*);
    WSDLEX32 static void endop(WSCbase*);
    WSDLEX32 static void setop(WSCbase*);
    WSDLEX32 static void addop(WSCbase*);
    WSDLEX32 static void delop(WSCbase*);

  protected:
    WSCmessageDialog* _msg;

  public:
    WSDLEX32 WSCtriggerEditor(WSCbase* base,char* name);
    WSDLEX32 virtual ~WSCtriggerEditor();
    WSDLEX32 WSClist* getList();
    WSDLEX32 virtual void onGuiPolicyChange(long);

    WSMFguiClassDef(WSCtriggerEditor,WSCtriggerEditorBASETYPE );
    WSMFversionDef(WSCtriggerEditor);
};
#endif
